@@ -1,4 +1,4 @@
-rowMads <- function(x, center=NULL, constant=1.4826, na.rm=FALSE, dim.=dim(x), centers=NULL, ...) {
+rowMads <- function(x, rows=NULL, cols=NULL, center=NULL, constant=1.4826, na.rm=FALSE, dim.=dim(x), centers=NULL, ...) {
   ## BACKWARD COMPATIBILITY:
   ## - Added to matrixStats 0.14.0.
   ## - Defunct in matrixStats (>= 0.15.0)
@@ -12,9 +12,20 @@ rowMads <- function(x, center=NULL, constant=1.4826, na.rm=FALSE, dim.=dim(x), c
     na.rm <- as.logical(na.rm)
     constant = as.numeric(constant)
     hasNAs <- TRUE
-    x <- .Call("rowMads", x, dim., constant, na.rm, hasNAs, TRUE, PACKAGE="matrixStats")
+    x <- .Call("rowMads", x, dim., rows, cols, constant, na.rm, hasNAs, TRUE, PACKAGE="matrixStats")
   } else {
+    # Apply subset on 'x'
+    if (is.vector(x)) dim(x) <- dim.
+    if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+    else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+    else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+    dim. <- dim(x)
+
+    # Apply subset on 'center'
+    if (!is.null(rows)) center <- center[rows]
+
     x <- x - center
+    if (is.null(dim(x))) dim(x) <- dim. # prevent from dim dropping
     x <- abs(x)
     x <- rowMedians(x, na.rm=na.rm, ...)
     x <- constant*x
@@ -23,7 +34,7 @@ rowMads <- function(x, center=NULL, constant=1.4826, na.rm=FALSE, dim.=dim(x), c
 } # rowMads()
 
 
-colMads <- function(x, center=NULL, constant=1.4826, na.rm=FALSE, dim.=dim(x), centers=NULL, ...) {
+colMads <- function(x, rows=NULL, cols=NULL, center=NULL, constant=1.4826, na.rm=FALSE, dim.=dim(x), centers=NULL, ...) {
   ## BACKWARD COMPATIBILITY:
   ## - Added to matrixStats 0.14.0.
   ## - Defunct in matrixStats (>= 0.15.0)
@@ -37,8 +48,18 @@ colMads <- function(x, center=NULL, constant=1.4826, na.rm=FALSE, dim.=dim(x), c
     na.rm <- as.logical(na.rm)
     constant = as.numeric(constant)
     hasNAs <- TRUE
-    x <- .Call("rowMads", x, dim., constant, na.rm, hasNAs, FALSE, PACKAGE="matrixStats")
+    x <- .Call("rowMads", x, dim., rows, cols, constant, na.rm, hasNAs, FALSE, PACKAGE="matrixStats")
   } else {
+    # Apply subset on 'x'
+    if (is.vector(x)) dim(x) <- dim.
+    if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+    else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+    else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+    dim. <- dim(x)
+
+    # Apply subset on 'center'
+    if (!is.null(cols)) center <- center[cols]
+
     ## SLOW:
     # for (cc in seq(length=ncol(x))) {
     #   x[,cc] <- x[,cc] - center[cc]
@@ -55,6 +76,8 @@ colMads <- function(x, center=NULL, constant=1.4826, na.rm=FALSE, dim.=dim(x), c
 
 ############################################################################
 # HISTORY:
+# 2015-05-30 [DJ]
+# o Supported subsetted computation.
 # 2015-02-10 [HB]
 # o CONSISTENCY: Renamed argument 'centers' of col- and rowMads() to
 #   'center'.  This is consistent with col- and rowVars().  Added
