@@ -17,6 +17,8 @@
 #   \item{w}{a vector of weights the same length as \code{x} giving the weights
 #            to use for each element of \code{x}. Negative weights are treated
 #            as zero weights. Default value is equal weight to all values.}
+#   \item{idxs}{A @vector indicating subset of elements
+#      to operate over. If @NULL, no subsetting is done.}
 #   \item{na.rm}{a logical value indicating whether @NA values in
 #            \code{x} should be stripped before the computation proceeds,
 #            or not.  If @NA, no check at all for @NAs is done.
@@ -57,7 +59,7 @@
 # @keyword "univar"
 # @keyword "robust"
 #*/############################################################################
-weightedMean <- function(x, w=NULL, na.rm=FALSE, refine=FALSE, ...) {
+weightedMean <- function(x, w=NULL, idxs=NULL, na.rm=FALSE, refine=FALSE, ...) {
   # Argument 'refine':
   refine <- as.logical(refine)
 
@@ -70,11 +72,13 @@ weightedMean <- function(x, w=NULL, na.rm=FALSE, refine=FALSE, ...) {
     w <- as.numeric(w)
   }
 
-  .Call("weightedMean", x, w, na.rm, refine, PACKAGE="matrixStats")
+  .Call("weightedMean", x, w, idxs, na.rm, refine, PACKAGE="matrixStats")
 } # weightedMean()
 
 ###############################################################################
 # HISTORY:
+# 2015-05-25 [DJ]
+# o Supported subsetted computation.
 # 2014-12-08
 # o Created.
 ###############################################################################
