@@ -1,6 +1,6 @@
 /***************************************************************************
  Public methods:
- SEXP signTabulate(SEXP x)
+ SEXP signTabulate(SEXP x, SEXP idxs)
 
  Copyright Henrik Bengtsson, 2014
  **************************************************************************/
@@ -8,31 +8,38 @@
 #include "types.h"
 #include "utils.h"
 
+
 #define METHOD signTabulate
+#define RETURN_TYPE void
+#define ARGUMENTS_LIST X_C_TYPE *x, R_xlen_t nx, void *idxs, R_xlen_t nidxs, double *ans
 
 #define X_TYPE 'i'
-#include "signTabulate_TYPE-template.h"
-
+#include "templates-gen-vector.h"
 #define X_TYPE 'r'
-#include "signTabulate_TYPE-template.h"
-
-#undef METHOD 
+#include "templates-gen-vector.h"
 
 
-SEXP signTabulate(SEXP x) {
+SEXP signTabulate(SEXP x, SEXP idxs) {
   SEXP ans = NILSXP;
+  R_xlen_t nx;
 
   /* Argument 'x': */
   assertArgVector(x, (R_TYPE_INT | R_TYPE_REAL), "x");
+  nx = xlength(x);
+
+  /* Argument 'idxs': */
+  R_xlen_t nidxs;
+  int idxsType;
+  void *cidxs = validateIndices(idxs, nx, 1, &nidxs, &idxsType);
 
   /* Double matrices are more common to use. */
   if (isReal(x)) {
     PROTECT(ans = allocVector(REALSXP, 6));
-    signTabulate_Real(REAL(x), xlength(x), REAL(ans));
+    signTabulate_Real[idxsType](REAL(x), nx, cidxs, nidxs, REAL(ans));
     UNPROTECT(1);
   } else if (isInteger(x)) {
     PROTECT(ans = allocVector(REALSXP, 4));
-    signTabulate_Integer(INTEGER(x), xlength(x), REAL(ans));
+    signTabulate_Integer[idxsType](INTEGER(x), nx, cidxs, nidxs, REAL(ans));
     UNPROTECT(1);
   }
 
@@ -42,6 +49,8 @@ SEXP signTabulate(SEXP x) {
 
 /***************************************************************************
  HISTORY:
+ 2015-07-04 [DJ]
+  o Supported subsetted computation.
  2014-06-04 [HB]
   o Created.
  **************************************************************************/
