@@ -1,6 +1,7 @@
 if (Sys.getenv("_R_CHECK_FULL_") != "" && Sys.getenv("_R_CHECK_USE_VALGRIND_") == "") {
 
-if (require("R.rsp")) {
+## Benchmarks requires knitr, which requires R (>= 3.0.2)
+if (require("R.rsp") && getRversion() >= "3.0.2") {
   html <- matrixStats:::benchmark('binCounts')
   print(html)
 }
