@@ -1,5 +1,21 @@
 library("matrixStats")
 
+rowDiffs_R <- function(x, lag=1L, differences=1L, ...) {
+  ncol2 <- ncol(x) - lag*differences
+  if (ncol2 <= 0) {
+    return(matrix(x[integer(0L)], nrow=nrow(x), ncol=0L))
+  }
+  suppressWarnings({
+    y <- apply(x, MARGIN=1L, FUN=diff, lag=lag, differences=differences)
+  })
+  y <- t(y)
+  dim(y) <- c(nrow(x), ncol2)
+  y
+}
+
+
+set.seed(0x42)
+
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # With and without some NAs
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -9,22 +25,24 @@ for (mode in c("integer", "double")) {
   for (addNA in c(FALSE, TRUE)) {
     cat("addNA=", addNA, "\n", sep="")
 
-    x <- matrix(1:100+0.1, nrow=20, ncol=5)
+    x <- matrix(sample(20*8)+0.1, nrow=20, ncol=8)
     if (addNA) {
       x[13:17,c(2,4)] <- NA_real_
     }
     storage.mode(x) <- mode
     str(x)
 
-    # Row/column ranges
-    for (na.rm in c(FALSE, TRUE)) {
-      cat("na.rm=", na.rm, "\n", sep="")
-      r0 <- t(apply(x, MARGIN=1L, FUN=diff, na.rm=na.rm))
-      r1 <- rowDiffs(x, na.rm=na.rm)
-      r2 <- t(colDiffs(t(x), na.rm=na.rm))
-      stopifnot(all.equal(r1, r2))
-      stopifnot(all.equal(r1, r0))
-      stopifnot(all.equal(r2, r0))
+    for (lag in 1:4) {
+      for (differences in 1:3) {
+        cat(sprintf("mode: %s, lag=%d, differences=%d\n", mode, lag, differences))
+        # Row/column ranges
+        r0 <- rowDiffs_R(x, lag=lag, differences=differences)
+        r1 <- rowDiffs(x, lag=lag, differences=differences)
+        r2 <- t(colDiffs(t(x), lag=lag, differences=differences))
+        stopifnot(all.equal(r1, r0))
+        stopifnot(all.equal(r2, r0))
+        stopifnot(all.equal(r1, r2))
+      }
     }
   } # for (addNA ...)
 } # for (mode ...)
@@ -39,31 +57,21 @@ for (mode in c("integer", "double")) {
   storage.mode(x) <- mode
   str(x)
 
-  for (na.rm in c(FALSE, TRUE)) {
-    cat("na.rm=", na.rm, "\n", sep="")
-    suppressWarnings({
-      r0 <- t(apply(x, MARGIN=1L, FUN=diff, na.rm=na.rm))
-    })
-    r1 <- rowDiffs(x, na.rm=na.rm)
-    r2 <- t(colDiffs(t(x), na.rm=na.rm))
-    stopifnot(all.equal(r1, r2))
-    stopifnot(all.equal(r1, r0))
-    stopifnot(all.equal(r2, r0))
-  }
+  r0 <- rowDiffs_R(x)
+  r1 <- rowDiffs(x)
+  r2 <- t(colDiffs(t(x)))
+  stopifnot(all.equal(r1, r2))
+  stopifnot(all.equal(r1, r0))
+  stopifnot(all.equal(r2, r0))
 } # for (mode ...)
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # A 1x1 matrix
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 x <- matrix(0, nrow=1, ncol=1)
-for (na.rm in c(FALSE, TRUE)) {
-  cat("na.rm=", na.rm, "\n", sep="")
-  suppressWarnings({
-    r0 <- t(apply(x, MARGIN=1L, FUN=diff, na.rm=na.rm))
-  })
-  r1 <- rowDiffs(x, na.rm=na.rm)
-  r2 <- t(colDiffs(t(x), na.rm=na.rm))
-  stopifnot(all.equal(r1, r2))
-  stopifnot(all.equal(r1, r0))
-  stopifnot(all.equal(r2, r0))
-}
+r0 <- rowDiffs_R(x)
+r1 <- rowDiffs(x)
+r2 <- t(colDiffs(t(x)))
+stopifnot(all.equal(r1, r2))
+stopifnot(all.equal(r1, r0))
+stopifnot(all.equal(r2, r0))
